# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.184.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictBool, StrictInt, StrictStr, field_validator
from typing import Optional
from typing_extensions import Annotated
from sonatype_iq_api_client.models.search_result_dto import SearchResultDTO

from sonatype_iq_api_client.api_client import ApiClient, RequestSerialized
from sonatype_iq_api_client.api_response import ApiResponse
from sonatype_iq_api_client.rest import RESTResponseType


class AdvancedSearchApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def create_search_index_async(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """create_search_index_async

        Use this method to create or rebuild the index for Advanced Search. This is a resource intensive operation. Avoid creating indexes during peak usage hours.  Permissions required: System Administrator

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_search_index_async_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def create_search_index_async_with_http_info(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """create_search_index_async

        Use this method to create or rebuild the index for Advanced Search. This is a resource intensive operation. Avoid creating indexes during peak usage hours.  Permissions required: System Administrator

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_search_index_async_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def create_search_index_async_without_preload_content(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """create_search_index_async

        Use this method to create or rebuild the index for Advanced Search. This is a resource intensive operation. Avoid creating indexes during peak usage hours.  Permissions required: System Administrator

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_search_index_async_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _create_search_index_async_serialize(
        self,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter




        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/v2/search/advanced/index',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_export_results(
        self,
        query: Annotated[StrictStr, Field(description="A well-formed search query.")],
        page_size: Annotated[Optional[StrictInt], Field(description="Enter the no. of results that should be visible per page, unset gives all results")] = None,
        page: Annotated[Optional[StrictInt], Field(description="Enter the page no. for the page containing results")] = None,
        all_components: Annotated[Optional[StrictBool], Field(description="Set to `true` to retrieve results that include components with no violations.")] = None,
        mode: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """get_export_results

        Use this method to generate a csv file containing your search results. The default delimiter in the generated file is comma. Use the advancedSearchCSVExportDelimiter property of the Configuration REST API to change the delimiter in the generated file.

        :param query: A well-formed search query. (required)
        :type query: str
        :param page_size: Enter the no. of results that should be visible per page, unset gives all results
        :type page_size: int
        :param page: Enter the page no. for the page containing results
        :type page: int
        :param all_components: Set to `true` to retrieve results that include components with no violations.
        :type all_components: bool
        :param mode:
        :type mode: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_export_results_serialize(
            query=query,
            page_size=page_size,
            page=page,
            all_components=all_components,
            mode=mode,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '409': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_export_results_with_http_info(
        self,
        query: Annotated[StrictStr, Field(description="A well-formed search query.")],
        page_size: Annotated[Optional[StrictInt], Field(description="Enter the no. of results that should be visible per page, unset gives all results")] = None,
        page: Annotated[Optional[StrictInt], Field(description="Enter the page no. for the page containing results")] = None,
        all_components: Annotated[Optional[StrictBool], Field(description="Set to `true` to retrieve results that include components with no violations.")] = None,
        mode: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """get_export_results

        Use this method to generate a csv file containing your search results. The default delimiter in the generated file is comma. Use the advancedSearchCSVExportDelimiter property of the Configuration REST API to change the delimiter in the generated file.

        :param query: A well-formed search query. (required)
        :type query: str
        :param page_size: Enter the no. of results that should be visible per page, unset gives all results
        :type page_size: int
        :param page: Enter the page no. for the page containing results
        :type page: int
        :param all_components: Set to `true` to retrieve results that include components with no violations.
        :type all_components: bool
        :param mode:
        :type mode: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_export_results_serialize(
            query=query,
            page_size=page_size,
            page=page,
            all_components=all_components,
            mode=mode,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '409': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_export_results_without_preload_content(
        self,
        query: Annotated[StrictStr, Field(description="A well-formed search query.")],
        page_size: Annotated[Optional[StrictInt], Field(description="Enter the no. of results that should be visible per page, unset gives all results")] = None,
        page: Annotated[Optional[StrictInt], Field(description="Enter the page no. for the page containing results")] = None,
        all_components: Annotated[Optional[StrictBool], Field(description="Set to `true` to retrieve results that include components with no violations.")] = None,
        mode: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """get_export_results

        Use this method to generate a csv file containing your search results. The default delimiter in the generated file is comma. Use the advancedSearchCSVExportDelimiter property of the Configuration REST API to change the delimiter in the generated file.

        :param query: A well-formed search query. (required)
        :type query: str
        :param page_size: Enter the no. of results that should be visible per page, unset gives all results
        :type page_size: int
        :param page: Enter the page no. for the page containing results
        :type page: int
        :param all_components: Set to `true` to retrieve results that include components with no violations.
        :type all_components: bool
        :param mode:
        :type mode: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_export_results_serialize(
            query=query,
            page_size=page_size,
            page=page,
            all_components=all_components,
            mode=mode,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '409': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_export_results_serialize(
        self,
        query,
        page_size,
        page,
        all_components,
        mode,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if query is not None:
            
            _query_params.append(('query', query))
            
        if page_size is not None:
            
            _query_params.append(('pageSize', page_size))
            
        if page is not None:
            
            _query_params.append(('page', page))
            
        if all_components is not None:
            
            _query_params.append(('allComponents', all_components))
            
        if mode is not None:
            
            _query_params.append(('mode', mode))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter




        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v2/search/advanced/export/csv',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def search_index(
        self,
        query: Annotated[Optional[StrictStr], Field(description="Enter your search query here")] = None,
        page_size: Annotated[Optional[StrictInt], Field(description="Enter the no. of results that should be visible per page")] = None,
        page: Annotated[Optional[StrictInt], Field(description="Enter the page no. for the page containing results")] = None,
        all_components: Annotated[Optional[StrictBool], Field(description="Set to `true` to retrieve results that include components with no violations")] = None,
        mode: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> SearchResultDTO:
        """search_index

        Use this method to perform an Advanced Search. 

        :param query: Enter your search query here
        :type query: str
        :param page_size: Enter the no. of results that should be visible per page
        :type page_size: int
        :param page: Enter the page no. for the page containing results
        :type page: int
        :param all_components: Set to `true` to retrieve results that include components with no violations
        :type all_components: bool
        :param mode:
        :type mode: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._search_index_serialize(
            query=query,
            page_size=page_size,
            page=page,
            all_components=all_components,
            mode=mode,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "SearchResultDTO",
            '409': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def search_index_with_http_info(
        self,
        query: Annotated[Optional[StrictStr], Field(description="Enter your search query here")] = None,
        page_size: Annotated[Optional[StrictInt], Field(description="Enter the no. of results that should be visible per page")] = None,
        page: Annotated[Optional[StrictInt], Field(description="Enter the page no. for the page containing results")] = None,
        all_components: Annotated[Optional[StrictBool], Field(description="Set to `true` to retrieve results that include components with no violations")] = None,
        mode: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[SearchResultDTO]:
        """search_index

        Use this method to perform an Advanced Search. 

        :param query: Enter your search query here
        :type query: str
        :param page_size: Enter the no. of results that should be visible per page
        :type page_size: int
        :param page: Enter the page no. for the page containing results
        :type page: int
        :param all_components: Set to `true` to retrieve results that include components with no violations
        :type all_components: bool
        :param mode:
        :type mode: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._search_index_serialize(
            query=query,
            page_size=page_size,
            page=page,
            all_components=all_components,
            mode=mode,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "SearchResultDTO",
            '409': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def search_index_without_preload_content(
        self,
        query: Annotated[Optional[StrictStr], Field(description="Enter your search query here")] = None,
        page_size: Annotated[Optional[StrictInt], Field(description="Enter the no. of results that should be visible per page")] = None,
        page: Annotated[Optional[StrictInt], Field(description="Enter the page no. for the page containing results")] = None,
        all_components: Annotated[Optional[StrictBool], Field(description="Set to `true` to retrieve results that include components with no violations")] = None,
        mode: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """search_index

        Use this method to perform an Advanced Search. 

        :param query: Enter your search query here
        :type query: str
        :param page_size: Enter the no. of results that should be visible per page
        :type page_size: int
        :param page: Enter the page no. for the page containing results
        :type page: int
        :param all_components: Set to `true` to retrieve results that include components with no violations
        :type all_components: bool
        :param mode:
        :type mode: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._search_index_serialize(
            query=query,
            page_size=page_size,
            page=page,
            all_components=all_components,
            mode=mode,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "SearchResultDTO",
            '409': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _search_index_serialize(
        self,
        query,
        page_size,
        page,
        all_components,
        mode,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if query is not None:
            
            _query_params.append(('query', query))
            
        if page_size is not None:
            
            _query_params.append(('pageSize', page_size))
            
        if page is not None:
            
            _query_params.append(('page', page))
            
        if all_components is not None:
            
            _query_params.append(('allComponents', all_components))
            
        if mode is not None:
            
            _query_params.append(('mode', mode))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v2/search/advanced',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.184.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from sonatype_iq_api_client.models.api_component_identifier_dtov2 import ApiComponentIdentifierDTOV2
from sonatype_iq_api_client.models.api_dependency_data_dto import ApiDependencyDataDTO
from sonatype_iq_api_client.models.api_license_data_dtov2 import ApiLicenseDataDTOV2
from sonatype_iq_api_client.models.api_security_data_dto import ApiSecurityDataDTO
from sonatype_iq_api_client.models.swid import Swid
from typing import Optional, Set
from typing_extensions import Self

class ApiReportComponentDTOV2(BaseModel):
    """
    ApiReportComponentDTOV2
    """ # noqa: E501
    component_identifier: Optional[ApiComponentIdentifierDTOV2] = Field(default=None, alias="componentIdentifier")
    cpe: Optional[StrictStr] = None
    dependency_data: Optional[ApiDependencyDataDTO] = Field(default=None, alias="dependencyData")
    display_name: Optional[StrictStr] = Field(default=None, alias="displayName")
    filenames: Optional[List[StrictStr]] = None
    hash: Optional[StrictStr] = None
    identification_source: Optional[StrictStr] = Field(default=None, alias="identificationSource")
    license_data: Optional[ApiLicenseDataDTOV2] = Field(default=None, alias="licenseData")
    match_state: Optional[StrictStr] = Field(default=None, alias="matchState")
    package_url: Optional[StrictStr] = Field(default=None, alias="packageUrl")
    pathnames: Optional[List[StrictStr]] = None
    proprietary: Optional[StrictBool] = None
    security_data: Optional[ApiSecurityDataDTO] = Field(default=None, alias="securityData")
    sha256: Optional[StrictStr] = None
    swid: Optional[Swid] = None
    third_party: Optional[StrictBool] = Field(default=None, alias="thirdParty")
    __properties: ClassVar[List[str]] = ["componentIdentifier", "cpe", "dependencyData", "displayName", "filenames", "hash", "identificationSource", "licenseData", "matchState", "packageUrl", "pathnames", "proprietary", "securityData", "sha256", "swid", "thirdParty"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ApiReportComponentDTOV2 from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of component_identifier
        if self.component_identifier:
            _dict['componentIdentifier'] = self.component_identifier.to_dict()
        # override the default output from pydantic by calling `to_dict()` of dependency_data
        if self.dependency_data:
            _dict['dependencyData'] = self.dependency_data.to_dict()
        # override the default output from pydantic by calling `to_dict()` of license_data
        if self.license_data:
            _dict['licenseData'] = self.license_data.to_dict()
        # override the default output from pydantic by calling `to_dict()` of security_data
        if self.security_data:
            _dict['securityData'] = self.security_data.to_dict()
        # override the default output from pydantic by calling `to_dict()` of swid
        if self.swid:
            _dict['swid'] = self.swid.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ApiReportComponentDTOV2 from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "componentIdentifier": ApiComponentIdentifierDTOV2.from_dict(obj["componentIdentifier"]) if obj.get("componentIdentifier") is not None else None,
            "cpe": obj.get("cpe"),
            "dependencyData": ApiDependencyDataDTO.from_dict(obj["dependencyData"]) if obj.get("dependencyData") is not None else None,
            "displayName": obj.get("displayName"),
            "filenames": obj.get("filenames"),
            "hash": obj.get("hash"),
            "identificationSource": obj.get("identificationSource"),
            "licenseData": ApiLicenseDataDTOV2.from_dict(obj["licenseData"]) if obj.get("licenseData") is not None else None,
            "matchState": obj.get("matchState"),
            "packageUrl": obj.get("packageUrl"),
            "pathnames": obj.get("pathnames"),
            "proprietary": obj.get("proprietary"),
            "securityData": ApiSecurityDataDTO.from_dict(obj["securityData"]) if obj.get("securityData") is not None else None,
            "sha256": obj.get("sha256"),
            "swid": Swid.from_dict(obj["swid"]) if obj.get("swid") is not None else None,
            "thirdParty": obj.get("thirdParty")
        })
        return _obj





# flake8: noqa

# import apis into api package
from sonatype_iq_api_client.api.advanced_search_api import AdvancedSearchApi
from sonatype_iq_api_client.api.application_categories_api import ApplicationCategoriesApi
from sonatype_iq_api_client.api.application_report_data_api import ApplicationReportDataApi
from sonatype_iq_api_client.api.applications_api import ApplicationsApi
from sonatype_iq_api_client.api.audit_logs_api import AuditLogsApi
from sonatype_iq_api_client.api.auto_policy_waiver_revocations_api import AutoPolicyWaiverRevocationsApi
from sonatype_iq_api_client.api.auto_policy_waivers_api import AutoPolicyWaiversApi
from sonatype_iq_api_client.api.claim_components_api import ClaimComponentsApi
from sonatype_iq_api_client.api.components_api import ComponentsApi
from sonatype_iq_api_client.api.composite_source_control_api import CompositeSourceControlApi
from sonatype_iq_api_client.api.composite_source_control_validator_api import CompositeSourceControlValidatorApi
from sonatype_iq_api_client.api.config_artifactory_connection_api import ConfigArtifactoryConnectionApi
from sonatype_iq_api_client.api.config_crowd_api import ConfigCrowdApi
from sonatype_iq_api_client.api.config_jira_api import ConfigJIRAApi
from sonatype_iq_api_client.api.config_mail_api import ConfigMailApi
from sonatype_iq_api_client.api.config_proxy_server_api import ConfigProxyServerApi
from sonatype_iq_api_client.api.config_reverse_proxy_authentication_api import ConfigReverseProxyAuthenticationApi
from sonatype_iq_api_client.api.config_saml_api import ConfigSAMLApi
from sonatype_iq_api_client.api.config_source_control_api import ConfigSourceControlApi
from sonatype_iq_api_client.api.configuration_api import ConfigurationApi
from sonatype_iq_api_client.api.cyclone_dx_api import CycloneDXApi
from sonatype_iq_api_client.api.data_retention_policies_api import DataRetentionPoliciesApi
from sonatype_iq_api_client.api.developer_priorities_api import DeveloperPrioritiesApi
from sonatype_iq_api_client.api.endpoints_api import EndpointsApi
from sonatype_iq_api_client.api.feature_configuration_api import FeatureConfigurationApi
from sonatype_iq_api_client.api.firewall_api import FirewallApi
from sonatype_iq_api_client.api.labels_api import LabelsApi
from sonatype_iq_api_client.api.license_legal_metadata_api import LicenseLegalMetadataApi
from sonatype_iq_api_client.api.malware_api import MalwareApi
from sonatype_iq_api_client.api.organizations_api import OrganizationsApi
from sonatype_iq_api_client.api.policies_api import PoliciesApi
from sonatype_iq_api_client.api.policy_evaluation_api import PolicyEvaluationApi
from sonatype_iq_api_client.api.policy_violation_details_api import PolicyViolationDetailsApi
from sonatype_iq_api_client.api.policy_waiver_reasons_api import PolicyWaiverReasonsApi
from sonatype_iq_api_client.api.policy_waivers_api import PolicyWaiversApi
from sonatype_iq_api_client.api.reports_api import ReportsApi
from sonatype_iq_api_client.api.repositories_api import RepositoriesApi
from sonatype_iq_api_client.api.role_memberships_api import RoleMembershipsApi
from sonatype_iq_api_client.api.roles_api import RolesApi
from sonatype_iq_api_client.api.scan_api import ScanApi
from sonatype_iq_api_client.api.search_api import SearchApi
from sonatype_iq_api_client.api.security_overrides_api import SecurityOverridesApi
from sonatype_iq_api_client.api.solutions_api import SolutionsApi
from sonatype_iq_api_client.api.source_control_api import SourceControlApi
from sonatype_iq_api_client.api.source_control_metrics_api import SourceControlMetricsApi
from sonatype_iq_api_client.api.spdx_api import SpdxApi
from sonatype_iq_api_client.api.telemetry_api import TelemetryApi
from sonatype_iq_api_client.api.user_tokens_api import UserTokensApi
from sonatype_iq_api_client.api.users_api import UsersApi
from sonatype_iq_api_client.api.vulnerabilities_api import VulnerabilitiesApi
from sonatype_iq_api_client.api.sbom_api import SbomApi

